Coverage for girder/__main__: 100%

# Coverage for girder/__main__ : 100%

## 0 statements 0 run 0 missing 11 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 | #!/usr/bin/env python # -*- coding: utf-8 -*- ############################################################################### # Copyright 2013 Kitware Inc. # # Licensed under the Apache License, Version 2.0 ( the "License" ); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. ############################################################################### import sys # pragma: no cover import cherrypy # pragma: no cover from girder.utility import server # pragma: no cover if __name__ == '__main__': # pragma: no cover if len(sys.argv) > 1 and sys.argv[1] == 'test': test = True else: test = False server.setup(test) cherrypy.engine.start() cherrypy.engine.block()